@@ -1,7 +1,7 @@
-#ifndef PYSAM_H
-#define PYSAM_H
+#ifndef @pysam@_PYSAM_H
+#define @pysam@_PYSAM_H
 
-#include "stdio.h"
+#include <stdio.h>
 
 extern FILE * @pysam@_stderr;
 
@@ -17,7 +17,7 @@ FILE * @pysam@_set_stderr(int fd);
 
 /*! set pysam standard output to point to file descriptor
 
-  Setting the stderr will close the previous stdout.
+  Setting the stdout will close the previous stdout.
  */
 FILE * @pysam@_set_stdout(int fd);
 
@@ -26,17 +26,15 @@ FILE * @pysam@_set_stdout(int fd);
  */
 void @pysam@_set_stdout_fn(const char * fn);
 
-/*! set pysam standard error to /dev/null.
+/*! close pysam standard error and set to NULL
   
-  Unsetting the stderr will close the previous stderr.
  */
-void @pysam@_unset_stderr(void);
+void @pysam@_close_stderr(void);
 
-/*! set pysam standard error to /dev/null.
+/*! close pysam standard output and set to NULL
   
-  Unsetting the stderr will close the previous stderr.
  */
-void @pysam@_unset_stdout(void);
+void @pysam@_close_stdout(void);
 
 int @pysam@_puts(const char *s);
 
