@@ -1,4 +1,7 @@
+# -*- coding: utf-8 -*-
+
 import os
+import glob
 import sys
 import unittest
 import pysam
@@ -633,6 +636,37 @@ class TestSubsetting(unittest.TestCase):
             inf.subset_samples(["NA00001"])
 
 
+class TestVCFVersions(unittest.TestCase):
+
+    def setUp(self):
+        self.files_to_test = (glob.glob(os.path.join(CBCF_DATADIR, "example_v*.vcf.gz")) +
+                              glob.glob(os.path.join(CBCF_DATADIR, "example_v*.vcf")) +
+                              glob.glob(os.path.join(CBCF_DATADIR, "example_v*.bcf")))
+    
+    def test_all_records_can_be_fetched(self):
+
+        for fn in self.files_to_test:
+            with pysam.VariantFile(fn) as inf:
+                records = list(inf.fetch())
+
+
+class TestUnicode(unittest.TestCase):
+    filename = "example_vcf43_with_utf8.vcf.gz"
+
+    def test_record_with_unicode(self):
+        with pysam.VariantFile(os.path.join(CBCF_DATADIR,
+                                            self.filename)) as inf:
+            records = list(inf.fetch("20", 2345677, 2345678))
+        self.assertEqual(len(records), 1)
+        record = records.pop()
+        self.assertEqual(
+            record.info["CLNVI"],
+            ('Institute_of_Human_Genetics', u'Friedrich-Alexander-Universität_Erlangen-Nürnberg'))
+        self.assertEqual(record.samples[0]["AN"], "alpha")
+        self.assertEqual(record.samples[1]["AN"], u"ä")
+        self.assertEqual(record.samples[2]["AN"], u"ü")
+                
+
 if __name__ == "__main__":
     # build data files
     print("building data files")
